@@ -20,7 +20,7 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(7.0.7);
+  our $VERSION = qv(8.0.0);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -89,11 +89,16 @@ sub tweak ($\@\@\@$$\%) {
           my $padix = $gv->padix;
           my (undef, @p)         = $cv_obj->PADLIST->ARRAY;
           $pads = [ map defined ? $_->object_2svref : $_, @p ];
-          $$pads[--$idx][$padix] = $method;
+          $$pads[--$idx][$padix] = $DEBUG ne "verify" ? $method : sub {
+            goto &$method if $method == $_[0]->can($method_name);
+            require Carp;
+            eval {warn "sub ", $cv_obj->GV->NAME // "__UNKNOWN__", " :sealed ", B::Deparse->new->coderef2text($method), "\n"};
+            Carp::confess ("sealed failed: $_[0]->$method_name method lookup differs from $class->$method_name:verified sub!");
+          };
           $$pads[$idx][$targ]   .= ":compiled";
         }
         else {
-          ${$methop->meth_sv->object_2svref} .= ":compiled";
+          ${$methop->meth_sv->object_2svref} .= $DEBUG ne "verify" ? ":compiled" : ":verified";
         }
 
         ++$tweaked;
